@@ -87,7 +87,8 @@ class Recipe:
       computer_partition_id)
     self.parameter_dict = self.computer_partition.getInstanceParameterDict()
     software_type = self.parameter_dict['slap_software_type']
-    self.logger.info('Deplying instance with software type %s' % software_type)
+    self.logger.info('Deploying instance with software type %s' % \
+        software_type)
 
     if software_type not in self.options:
       if 'default' in self.options:
